@@ -85,6 +85,32 @@ func TestPodLifeTime(t *testing.T) {
 	p5.ObjectMeta.OwnerReferences = ownerRef4
 	p6.ObjectMeta.OwnerReferences = ownerRef4
 
+	// Setup two old pods with different status phases
+	p9 := test.BuildTestPod("p9", 100, 0, node.Name, nil)
+	p9.Namespace = "dev"
+	p9.ObjectMeta.CreationTimestamp = olderPodCreationTime
+	p10 := test.BuildTestPod("p10", 100, 0, node.Name, nil)
+	p10.Namespace = "dev"
+	p10.ObjectMeta.CreationTimestamp = olderPodCreationTime
+
+	p9.Status.Phase = "Pending"
+	p10.Status.Phase = "Running"
+	p9.ObjectMeta.OwnerReferences = ownerRef1
+	p10.ObjectMeta.OwnerReferences = ownerRef1
+
+	p11 := test.BuildTestPod("p11", 100, 0, node.Name, func(pod *v1.Pod) {
+		pod.Spec.Volumes = []v1.Volume{
+			{
+				Name: "pvc", VolumeSource: v1.VolumeSource{
+					PersistentVolumeClaim: &v1.PersistentVolumeClaimVolumeSource{ClaimName: "foo"},
+				},
+			},
+		}
+		pod.Namespace = "dev"
+		pod.ObjectMeta.CreationTimestamp = olderPodCreationTime
+		pod.ObjectMeta.OwnerReferences = ownerRef1
+	})
+
 	var maxLifeTime uint = 600
 	testCases := []struct {
 		description             string
@@ -92,13 +118,14 @@ func TestPodLifeTime(t *testing.T) {
 		maxPodsToEvictPerNode   int
 		pods                    []v1.Pod
 		expectedEvictedPodCount int
+		ignorePvcPods           bool
 	}{
 		{
 			description: "Two pods in the `dev` Namespace, 1 is new and 1 very is old. 1 should be evicted.",
 			strategy: api.DeschedulerStrategy{
 				Enabled: true,
 				Params: &api.StrategyParameters{
-					MaxPodLifeTimeSeconds: &maxLifeTime,
+					PodLifeTime: &api.PodLifeTime{MaxPodLifeTimeSeconds: &maxLifeTime},
 				},
 			},
 			maxPodsToEvictPerNode:   5,
@@ -110,7 +137,7 @@ func TestPodLifeTime(t *testing.T) {
 			strategy: api.DeschedulerStrategy{
 				Enabled: true,
 				Params: &api.StrategyParameters{
-					MaxPodLifeTimeSeconds: &maxLifeTime,
+					PodLifeTime: &api.PodLifeTime{MaxPodLifeTimeSeconds: &maxLifeTime},
 				},
 			},
 			maxPodsToEvictPerNode:   5,
@@ -122,7 +149,7 @@ func TestPodLifeTime(t *testing.T) {
 			strategy: api.DeschedulerStrategy{
 				Enabled: true,
 				Params: &api.StrategyParameters{
-					MaxPodLifeTimeSeconds: &maxLifeTime,
+					PodLifeTime: &api.PodLifeTime{MaxPodLifeTimeSeconds: &maxLifeTime},
 				},
 			},
 			maxPodsToEvictPerNode:   5,
@@ -134,13 +161,53 @@ func TestPodLifeTime(t *testing.T) {
 			strategy: api.DeschedulerStrategy{
 				Enabled: true,
 				Params: &api.StrategyParameters{
-					MaxPodLifeTimeSeconds: &maxLifeTime,
+					PodLifeTime: &api.PodLifeTime{MaxPodLifeTimeSeconds: &maxLifeTime},
 				},
 			},
 			maxPodsToEvictPerNode:   5,
 			pods:                    []v1.Pod{*p7, *p8},
 			expectedEvictedPodCount: 0,
 		},
+		{
+			description: "Two old pods with different status phases. 1 should be evicted.",
+			strategy: api.DeschedulerStrategy{
+				Enabled: true,
+				Params: &api.StrategyParameters{
+					PodLifeTime: &api.PodLifeTime{
+						MaxPodLifeTimeSeconds: &maxLifeTime,
+						PodStatusPhases:       []string{"Pending"},
+					},
+				},
+			},
+			maxPodsToEvictPerNode:   5,
+			pods:                    []v1.Pod{*p9, *p10},
+			expectedEvictedPodCount: 1,
+		},
+		{
+			description: "does not evict pvc pods with ignorePvcPods set to true",
+			strategy: api.DeschedulerStrategy{
+				Enabled: true,
+				Params: &api.StrategyParameters{
+					PodLifeTime: &api.PodLifeTime{MaxPodLifeTimeSeconds: &maxLifeTime},
+				},
+			},
+			maxPodsToEvictPerNode:   5,
+			pods:                    []v1.Pod{*p11},
+			expectedEvictedPodCount: 0,
+			ignorePvcPods:           true,
+		},
+		{
+			description: "evicts pvc pods with ignorePvcPods set to false (or unset)",
+			strategy: api.DeschedulerStrategy{
+				Enabled: true,
+				Params: &api.StrategyParameters{
+					PodLifeTime: &api.PodLifeTime{MaxPodLifeTimeSeconds: &maxLifeTime},
+				},
+			},
+			maxPodsToEvictPerNode:   5,
+			pods:                    []v1.Pod{*p11},
+			expectedEvictedPodCount: 1,
+		},
 	}
 
 	for _, tc := range testCases {
@@ -158,6 +225,7 @@ func TestPodLifeTime(t *testing.T) {
 			tc.maxPodsToEvictPerNode,
 			[]*v1.Node{node},
 			false,
+			tc.ignorePvcPods,
 		)
 
 		PodLifeTime(ctx, fakeClient, tc.strategy, []*v1.Node{node}, podEvictor)
